@@ -11,4 +11,6 @@ f <- function() {
 }
 
 m1 <- f()
-profile(m1)
+p <- profile(m1)
+## FIXME: check results (need to save in an environment-friendly way!)
+print(head(as.data.frame(p)),digits=3)
